/**
 * @file tuya_ai_toy.h
 * @brief 
 * @version 0.1
 * @date 2024-11-01
 * 
 * @copyright Copyright (c) 2024 Tuya Inc. All Rights Reserved.
 * 
 * Permission is hereby granted, to any person obtaining a copy of this software and
 * associated documentation files (the "Software"), Under the premise of complying 
 * with the license of the third-party open source software contained in the software,
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software.
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 */

#ifndef __TUAY_AI_TOY_H__
#define __TUAY_AI_TOY_H__

#include "tuya_cloud_types.h"
#include "tuya_cloud_com_defs.h"
#include "tkl_audio.h"
#include "tuya_ai_proc.h"
#include "tuya_ai_mp3_player.h"


#ifdef __cplusplus
extern "C" {
#endif

#define TY_AI_TRIGGER_MODE_HOLD 0
#define TY_AI_TRIGGER_MODE_ONE_SHOT 1

// config struct
typedef struct {
    TUYA_GPIO_NUM_E reset_key_pin;      // reset key pin
    TUYA_GPIO_NUM_E audio_trigger_pin;  // audio trigger pin
    TUYA_GPIO_NUM_E spk_en_pin;         // speaker enable pin
    BOOL_T trigger_mode;                // trigger mode, 0: hold trigger mode, 1: one shot trigger mode
} TY_AI_TOY_PARA_T;

// default config, hold trigger mode, pid: xqagkeaoe0l37wdu
#define TY_AI_PROC_PARA_DEF { \
    .reset_key_pin = TUYA_GPIO_NUM_36, \
    .audio_trigger_pin = TUYA_GPIO_NUM_29, \
    .spk_en_pin = TUYA_GPIO_NUM_27, \
    .trigger_mode = TY_AI_TRIGGER_MODE_HOLD, \
}

// default config, one shot trigger mode, pid: xqagkeaoe0l37wdu
#define TY_AI_PROC_PARA_DEF2 { \
    .reset_key_pin = TUYA_GPIO_NUM_36, \
    .audio_trigger_pin = TUYA_GPIO_NUM_29, \
    .spk_en_pin = TUYA_GPIO_NUM_27, \
    .trigger_mode = TY_AI_TRIGGER_MODE_ONE_SHOT, \
}

// custom board config, pid: xqagkeaoe0l37wdu
#define TY_AI_PROC_PARA_CUSTOM { \
    .reset_key_pin = TUYA_GPIO_NUM_16, \
    .audio_trigger_pin = TUYA_GPIO_NUM_17, \
    .spk_en_pin = TUYA_GPIO_NUM_30, \
    .trigger_mode = TY_AI_TRIGGER_MODE_HOLD, \
}

// AI box config, pid: tsqwarw3fkyzzgbf
#define TY_AI_PROC_PARA_AIBOX { \
    .reset_key_pin = TUYA_GPIO_NUM_15, \
    .audio_trigger_pin = TUYA_GPIO_NUM_33, \
    .spk_en_pin = TUYA_GPIO_NUM_27, \
    .trigger_mode = TY_AI_TRIGGER_MODE_ONE_SHOT, \
}

#define TY_AI_PROC_PARA_AIBOX_HOLD { \
    .reset_key_pin = TUYA_GPIO_NUM_15, \
    .audio_trigger_pin = TUYA_GPIO_NUM_33, \
    .spk_en_pin = TUYA_GPIO_NUM_27, \
    .trigger_mode = TY_AI_TRIGGER_MODE_HOLD, \
}

/**
 * @brief AI toy dp command callback
 *
 * @param dp
 */
VOID ty_ai_toy_dp_cmd_cb(IN CONST TY_RECV_OBJ_DP_S *dp);

/**
 * @brief AI toy init
 * 
 * @return int 0: success, -1: fail
 */
OPERATE_RET ty_ai_toy_init(void);

/**
 * @brief AI toy start
 * 
 * @return int 0: success, -1: fail
 */
OPERATE_RET ty_ai_toy_start(void);

void ty_ai_toy_set_stat_start();

void ty_ai_toy_set_stat_stop();

void ty_ai_toy_set_trigger_mode_one_shot();

#ifdef __cplusplus
}
#endif

#endif // __TUAY_AI_TOY_H__
